require '../../spec_helper'

describe 'Hiker', ->

  describe '#urlMatchesScheme', ->

    it 'should match /user => /user', ->
      expect(Hiker.urlMatchesScheme('/user', '/user')).toBe true

    it 'should match /user/123 => /user/:id', ->
      expect(Hiker.urlMatchesScheme('/user/123', '/user/:id')).toBe true

    it 'should match /user/123/books/4 => /user/:id/books/:book_id', ->
      expect(Hiker.urlMatchesScheme('/user/123/books/4', '/user/:id/books/:book_id')).toBe true

    it 'should match /user/123/books/4/slices => /user/:user_id/books/:id/slices', ->
      expect(Hiker.urlMatchesScheme('/user/123/books/4/slices', '/user/:user_id/books/:id/slices')).toBe true

    it 'should match /books.json => /books', ->
      expect(Hiker.urlMatchesScheme('/books.json', '/books')).toBe true

    it 'should match /books/1.json => /books/:id', ->
      expect(Hiker.urlMatchesScheme('/books/1.json', '/books/:id')).toBe true

    it 'should not match /books/1 => /books', ->
      expect(Hiker.urlMatchesScheme('/books/1', '/books')).toBe false

    it 'should not match /books/1 => /books/:id/pages', ->
      expect(Hiker.urlMatchesScheme('/books/1', '/books/:id/pages')).toBe false

    it 'should not match /books/1238adasd7/pages => /books/:id', ->
      expect(Hiker.urlMatchesScheme('/books/1238adasd7/pages', '/books/:id')).toBe false

    it 'should not match /books/test.json => /books/:id', ->
      expect(Hiker.urlMatchesScheme('/books/test.json', '/books/:id')).toBe false

    it 'should ignore url params', ->
      expect(Hiker.urlMatchesScheme('/books?order=asc', '/books')).toBe true


  describe '#build', ->

    it 'should return an object that includes matched params', ->
      expect(Hiker.build('/user/5', '/user/:id')).toEqual({ id: '5' })
      expect(Hiker.build('/user/5/books/10', '/user/:user_id/books/:id')).toEqual({ user_id: '5', id: '10' })
      expect(Hiker.build('/product/zaghhe234nswua-dsad', '/product/:token')).toEqual({ token: 'zaghhe234nswua-dsad' })
      expect(Hiker.build('/users?order=asc', '/users')).toEqual({ order: 'asc' })
      expect(Hiker.build('/users/?order=asc', '/users')).toEqual({ order: 'asc' })
      expect(Hiker.build('/user/1?order=asc', '/user/:id')).toEqual({ id: "1", order: 'asc' })
      expect(Hiker.build('/user/1/?order=asc', '/user/:id')).toEqual({ id: "1", order: 'asc' })
      expect(Hiker.build('/?order=asc', '/')).toEqual({ order: 'asc' })
